import { NestFactory } from '@nestjs/core';
import { AppModule } from './app.module';
import { TrpcRouter } from './trpc/trpc.router';
import { WebSocketService } from './socket/websocket.service';

/**
 * 启动 NestJS 应用程序的引导函数
 * 该函数初始化 NestJS 应用程序，配置 CORS，初始化 WebSocket 服务，应用 TRPC 中间件，并启动服务器监听指定端口
 */
async function bootstrap() {
  // 创建 NestJS 应用实例，使用 AppModule 作为根模块
  const app = await NestFactory.create(AppModule);

  // 启用 CORS 并允许所有来源
  app.enableCors({ //允许跨域
    origin: '*',
  });
  // 从 NestJS 应用实例中获取 WebSocketService 实例
  const wsService = app.get(WebSocketService);
  // 初始化 WebSocket 服务，传入 HTTP 服务器实例
  await wsService.initialize(app.getHttpServer());
  // 从 NestJS 应用实例中获取 TrpcRouter 实例
  const trpc = app.get(TrpcRouter);
  // 应用 TRPC 中间件到 NestJS 应用实例
  trpc.applyMiddleware(app);

  // 获取环境变量中的服务器端口，如果未设置则使用默认端口 3000
  const port = process.env.SERVER_PORT || 3000;

  // 启动服务器监听指定端口
  await app.listen(port);
}
// 调用引导函数启动应用程序
bootstrap();
